searchNodes=[{"ref":"Cldr.Unit.html","title":"Cldr.Unit","type":"module","doc":"Supports the CLDR Units definitions which provide for the localization of many unit types. The primary public API defines: Cldr.Unit.to_string/3 which, given a number and a unit name or unit list will output a localized string Cldr.Unit.units/0 identifies the available units for localization Cldr.Unit.{add, sub, mult, div}/2 to support basic unit mathematics between units of compatible type (like length or volume) Cldr.Unit.convert/2 to convert one unit to another unit as long as they are convertable. Cldr.Unit.decompose/2 to take a unit and return a list of units decomposed by a list of smaller units."},{"ref":"Cldr.Unit.html#add/2","title":"Cldr.Unit.add/2","type":"function","doc":"See Cldr.Unit.Math.add/2."},{"ref":"Cldr.Unit.html#add!/2","title":"Cldr.Unit.add!/2","type":"function","doc":"See Cldr.Unit.Math.add!/2."},{"ref":"Cldr.Unit.html#best_match/2","title":"Cldr.Unit.best_match/2","type":"function","doc":"Returns the unit closed in jaro distance to the provided unit Arguments unit is any unit returned by Cldr.Unit.units/0 or by Cldr.Unit.new/2 distance is a float between 0.0 and 1.0 representing the jaro distance above which a unit must match in order to be returned. The default is 0.75 Returns a Unit.t struct or nil Examples iex&gt; Cldr.Unit.best_match :ft :fathom iex&gt; Cldr.Unit.best_match :zippity nil"},{"ref":"Cldr.Unit.html#compatible?/2","title":"Cldr.Unit.compatible?/2","type":"function","doc":"Returns a boolean indicating if two units are of the same unit type. Options unit_1 and unit_2 are any units returned by Cldr.Unit.new/2 or units returned by Cldr.Unit.units/0 Returns true or false Examples iex&gt; Cldr.Unit.compatible? :foot, :meter true iex&gt; Cldr.Unit.compatible? Cldr.Unit.new!(:foot, 23), :meter true iex&gt; Cldr.Unit.compatible? :foot, :liter false"},{"ref":"Cldr.Unit.html#compatible_units/2","title":"Cldr.Unit.compatible_units/2","type":"function","doc":"Returns a list of units that are compatible with the provided unit. Arguments unit is any unit returned by Cldr.Unit.units/0 or by Cldr.Unit.new/2 options is a keyword list of options Options :jaro is a boolean which determines if the match is to use the jaro distance. The default is false distance is a float between 0.0 and 1.0 representing the jaro distance above which a unit must match in order to be returned. The default is 0.75 Returns a list of tuples of the form {jaro_distance, unit} sorted in decending jaro distance order, or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.compatible_units :foot [:astronomical_unit, :centimeter, :decimeter, :fathom, :foot, :furlong, :inch, :kilometer, :light_year, :meter, :micrometer, :mile, :mile_scandinavian, :millimeter, :nanometer, :nautical_mile, :parsec, :picometer, :point, :solar_radius, :yard] iex&gt; Cldr.Unit.compatible_units :me, jaro: true [{0.7999999999999999, :meter}]"},{"ref":"Cldr.Unit.html#convert/2","title":"Cldr.Unit.convert/2","type":"function","doc":"See Cldr.Unit.Conversion.convert/2."},{"ref":"Cldr.Unit.html#decompose/2","title":"Cldr.Unit.decompose/2","type":"function","doc":"Decomposes a unit into subunits. Any list compatible units can be provided however a list of units of decreasing scale is recommended. For example [:foot, :inch] or [:kilometer, :meter, :centimeter, :millimeter] Examples iex&gt; u = Cldr.Unit.new(10.3, :foot) iex&gt; Cldr.Unit.decompose u, [:foot, :inch] [Cldr.Unit.new(:foot, 10), Cldr.Unit.new(:inch, 4)] iex&gt; u = Cldr.Unit.new(:centimeter, 1111) iex&gt; Cldr.Unit.decompose u, [:kilometer, :meter, :centimeter, :millimeter] [Cldr.Unit.new(:meter, 11), Cldr.Unit.new(:centimeter, 11)]"},{"ref":"Cldr.Unit.html#default_style/0","title":"Cldr.Unit.default_style/0","type":"function","doc":"Returns the default formatting style. Example iex&gt; Cldr.Unit.default_style :long"},{"ref":"Cldr.Unit.html#div/2","title":"Cldr.Unit.div/2","type":"function","doc":"See Cldr.Unit.Math.div/2."},{"ref":"Cldr.Unit.html#div!/2","title":"Cldr.Unit.div!/2","type":"function","doc":"See Cldr.Unit.Math.div!/2."},{"ref":"Cldr.Unit.html#jaro_match/2","title":"Cldr.Unit.jaro_match/2","type":"function","doc":"Returns a list of units that are within the specified jaro distance of the provided unit. Arguments unit is any unit returned by Cldr.Unit.units/0 or by Cldr.Unit.new/2 distance is a float between 0.0 and 1.0 representing the jaro distance above which a unit must match in order to be returned. The default is 0.75 Returns a list of tagged tuples of the form {jaro_distance, unit} sorted in decending jaro distance order or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.jaro_match :foot [{1.0, :foot}] iex&gt; Cldr.Unit.jaro_match :meter [ {1.0, :meter}, {0.7708333333333334, :meter_per_second}, {0.7592592592592592, :kilometer_per_hour} ]"},{"ref":"Cldr.Unit.html#mult/2","title":"Cldr.Unit.mult/2","type":"function","doc":"See Cldr.Unit.Math.mult/2."},{"ref":"Cldr.Unit.html#mult!/2","title":"Cldr.Unit.mult!/2","type":"function","doc":"See Cldr.Unit.Math.mult!/2."},{"ref":"Cldr.Unit.html#new/2","title":"Cldr.Unit.new/2","type":"function","doc":"Returns a new Unit.t struct. Options value is any float, integer or Decimal unit is any unit returned by Cldr.Unit.units Returns unit or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.new(23, :gallon) #Unit&lt;:gallon, 23&gt; iex&gt; Cldr.Unit.new(:gallon, 23) #Unit&lt;:gallon, 23&gt; iex&gt; Cldr.Unit.new(14, :gadzoots) {:error, {Cldr.UnknownUnitError, &quot;The unit :gadzoots is not known.&quot;}}"},{"ref":"Cldr.Unit.html#new!/2","title":"Cldr.Unit.new!/2","type":"function","doc":"Returns a new Unit.t struct or raises on error. Options value is any float, integer or Decimal unit is any unit returned by Cldr.Unit.units/0 Returns unit or raises an exception Examples iex&gt; Cldr.Unit.new! 23, :gallon #Unit&lt;:gallon, 23&gt; Cldr.Unit.new! 14, :gadzoots ** (Cldr.UnknownUnitError) The unit :gadzoots is not known. (ex_cldr_units) lib/cldr/unit.ex:57: Cldr.Unit.new!/2"},{"ref":"Cldr.Unit.html#round/1","title":"Cldr.Unit.round/1","type":"function","doc":"See Cldr.Unit.Math.round/1."},{"ref":"Cldr.Unit.html#round/2","title":"Cldr.Unit.round/2","type":"function","doc":"See Cldr.Unit.Math.round/2."},{"ref":"Cldr.Unit.html#round/3","title":"Cldr.Unit.round/3","type":"function","doc":"See Cldr.Unit.Math.round/3."},{"ref":"Cldr.Unit.html#styles/0","title":"Cldr.Unit.styles/0","type":"function","doc":"Returns the known styles for a unit. Example iex&gt; Cldr.Unit.styles [:long, :short, :narrow]"},{"ref":"Cldr.Unit.html#sub/2","title":"Cldr.Unit.sub/2","type":"function","doc":"See Cldr.Unit.Math.sub/2."},{"ref":"Cldr.Unit.html#sub!/2","title":"Cldr.Unit.sub!/2","type":"function","doc":"See Cldr.Unit.Math.sub!/2."},{"ref":"Cldr.Unit.html#to_string/3","title":"Cldr.Unit.to_string/3","type":"function","doc":"Formats a number into a string according to a unit definition for a locale. Arguments list_or_number is any number (integer, float or Decimal) or a Cldr.Unit.t() struct or a list of Cldr.Unit.t() structs backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. options is a keyword list of options Options :unit is any unit returned by Cldr.Unit.units/1. Ignored if the number to be formatted is a Cldr.Unit.t() struct :locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct. The default is Cldr.get_current_locale/0 :style is one of those returned by Cldr.Unit.styles. The current styles are :long, :short and :narrow. The default is style: :long :list_options is a keyword list of options for formatting a list which is passed through to Cldr.List.to_string/3. This is only applicable when formatting a list of units. Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns {:ok, formatted_string} or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.to_string 123, MyApp.Cldr, unit: :gallon {:ok, &quot;123 gallons&quot;} iex&gt; Cldr.Unit.to_string 1, MyApp.Cldr, unit: :gallon {:ok, &quot;1 gallon&quot;} iex&gt; Cldr.Unit.to_string 1, MyApp.Cldr, unit: :gallon, locale: &quot;af&quot; {:ok, &quot;1 gelling&quot;} iex&gt; Cldr.Unit.to_string 1, MyApp.Cldr, unit: :gallon, locale: &quot;bs&quot; {:ok, &quot;1 galon&quot;} iex&gt; Cldr.Unit.to_string 1234, MyApp.Cldr, unit: :gallon, format: :long {:ok, &quot;1 thousand gallons&quot;} iex&gt; Cldr.Unit.to_string 1234, MyApp.Cldr, unit: :gallon, format: :short {:ok, &quot;1K gallons&quot;} iex&gt; Cldr.Unit.to_string 1234, MyApp.Cldr, unit: :megahertz {:ok, &quot;1,234 megahertz&quot;} iex&gt; Cldr.Unit.to_string 1234, MyApp.Cldr, unit: :megahertz, style: :narrow {:ok, &quot;1,234MHz&quot;} iex&gt; unit = Cldr.Unit.new(123, :foot) iex&gt; Cldr.Unit.to_string unit, MyApp.Cldr {:ok, &quot;123 feet&quot;} iex&gt; Cldr.Unit.to_string 123, MyApp.Cldr, unit: :megabyte, locale: &quot;en&quot;, style: :unknown {:error, {Cldr.UnknownFormatError, &quot;The unit style :unknown is not known.&quot;}} iex&gt; Cldr.Unit.to_string 123, MyApp.Cldr, unit: :blabber, locale: &quot;en&quot; {:error, {Cldr.UnknownUnitError, &quot;The unit :blabber is not known.&quot;}}"},{"ref":"Cldr.Unit.html#to_string!/3","title":"Cldr.Unit.to_string!/3","type":"function","doc":"Formats a list using to_string/3 but raises if there is an error. Arguments number is any number (integer, float or Decimal) or a Cldr.Unit.t() struct backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. options is a keyword list Options :unit is any unit returned by Cldr.Unit.units/1. Ignored if the number to be formatted is a Cldr.Unit.t() struct :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_current_locale/0 :style is one of those returned by Cldr.Unit.available_styles. The current styles are :long, :short and :narrow. The default is style: :long Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns formatted_string or raises and exception Examples iex&gt; Cldr.Unit.to_string! 123, MyApp.Cldr, unit: :gallon &quot;123 gallons&quot; iex&gt; Cldr.Unit.to_string! 1, MyApp.Cldr, unit: :gallon &quot;1 gallon&quot; iex&gt; Cldr.Unit.to_string! 1, MyApp.Cldr, unit: :gallon, locale: &quot;af&quot; &quot;1 gelling&quot;"},{"ref":"Cldr.Unit.html#unit_tree/0","title":"Cldr.Unit.unit_tree/0","type":"function","doc":"Returns a list of the unit types and associated units Example Cldr.Unit.unit_tree =&gt; %{ acceleration: [:g_force, :meter_per_second_squared], angle: [:arc_minute, :arc_second, :degree, :radian, :revolution], area: [:acre, :hectare, :square_centimeter, :square_foot, :square_inch, :square_kilometer, :square_meter, :square_mile, :square_yard], concentr: [:karat, :milligram_per_deciliter, :millimole_per_liter, :part_per_million] ..."},{"ref":"Cldr.Unit.html#unit_type/1","title":"Cldr.Unit.unit_type/1","type":"function","doc":"Returns the units associated with a given unit type Options unit is any units returned by Cldr.Unit.new/2 or units returned by Cldr.Unit.units/0 Returns a valid unit or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.unit_type :pint_metric :volume iex&gt; Cldr.Unit.unit_type :stone :mass"},{"ref":"Cldr.Unit.html#unit_types/0","title":"Cldr.Unit.unit_types/0","type":"function","doc":"Returns a list of the known unit categories. Example iex&gt; Cldr.Unit.unit_types [:acceleration, :angle, :area, :concentr, :consumption, :coordinate, :digital, :duration, :electric, :energy, :force, :frequency, :length, :light, :mass, :power, :pressure, :speed, :temperature, :torque, :volume]"},{"ref":"Cldr.Unit.html#units/0","title":"Cldr.Unit.units/0","type":"function","doc":"Returns the known units. Example Cldr.Unit.units [:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit, :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century, :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter, :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter, :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong, :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz, :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower, :hour, :inch, ...]"},{"ref":"Cldr.Unit.html#units/1","title":"Cldr.Unit.units/1","type":"function","doc":"Returns the units for a given unit type Arguments type is any unit type returned by Cldr.Unit.unit_types/0 Returns a list of units Examples iex&gt; Cldr.Unit.units(:length) [:astronomical_unit, :centimeter, :decimeter, :fathom, :foot, :furlong, :inch, :kilometer, :light_year, :meter, :micrometer, :mile, :mile_scandinavian, :millimeter, :nanometer, :nautical_mile, :parsec, :picometer, :point, :solar_radius, :yard]"},{"ref":"Cldr.Unit.html#units_for/3","title":"Cldr.Unit.units_for/3","type":"function","doc":""},{"ref":"Cldr.Unit.html#validate_style/1","title":"Cldr.Unit.validate_style/1","type":"function","doc":"Validates a unit style and normalizes it to a standard downcased atom form"},{"ref":"Cldr.Unit.html#validate_unit/1","title":"Cldr.Unit.validate_unit/1","type":"function","doc":"Validates a unit name and normalizes it to a standard downcased atom form"},{"ref":"Cldr.Unit.html#value/1","title":"Cldr.Unit.value/1","type":"function","doc":"Return the value of the Unit struct Arguments unit is any unit returned by Cldr.Unit.new/2 Returns an integer, float or Decimal representing the amount of the unit Example iex&gt; Cldr.Unit.value Cldr.Unit.new(:kilogram, 23) 23"},{"ref":"Cldr.Unit.html#zero/1","title":"Cldr.Unit.zero/1","type":"function","doc":"Returns a new unit of the same unit type but with a zero value. Example iex&gt; u = Cldr.Unit.new(:foot, 23.3) #Unit&lt;:foot, 23.3&gt; iex&gt; Cldr.Unit.zero(u) #Unit&lt;:foot, 0.0&gt;"},{"ref":"Cldr.Unit.html#zero?/1","title":"Cldr.Unit.zero?/1","type":"function","doc":"Returns a boolean indicating whether a given unit has a zero value. Examples iex&gt; u = Cldr.Unit.new(:foot, 23.3) #Unit&lt;:foot, 23.3&gt; iex&gt; Cldr.Unit.zero?(u) false iex&gt; u = Cldr.Unit.new(:foot, 0) #Unit&lt;:foot, 0&gt; iex&gt; Cldr.Unit.zero?(u) true"},{"ref":"Cldr.Unit.html#t:style/0","title":"Cldr.Unit.style/0","type":"type","doc":""},{"ref":"Cldr.Unit.html#t:t/0","title":"Cldr.Unit.t/0","type":"type","doc":""},{"ref":"Cldr.Unit.html#t:unit/0","title":"Cldr.Unit.unit/0","type":"type","doc":""},{"ref":"Cldr.Unit.html#t:value/0","title":"Cldr.Unit.value/0","type":"type","doc":""},{"ref":"Cldr.Unit.Alias.html","title":"Cldr.Unit.Alias","type":"module","doc":""},{"ref":"Cldr.Unit.Alias.html#alias/1","title":"Cldr.Unit.Alias.alias/1","type":"function","doc":""},{"ref":"Cldr.Unit.Alias.html#aliases/0","title":"Cldr.Unit.Alias.aliases/0","type":"function","doc":""},{"ref":"Cldr.Unit.Backend.html","title":"Cldr.Unit.Backend","type":"module","doc":""},{"ref":"Cldr.Unit.Backend.html#define_unit_module/1","title":"Cldr.Unit.Backend.define_unit_module/1","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.html","title":"Cldr.Unit.Conversion","type":"module","doc":"Unit conversion functions for the units defined in Cldr."},{"ref":"Cldr.Unit.Conversion.html#convert/2","title":"Cldr.Unit.Conversion.convert/2","type":"function","doc":"Convert one unit into another unit of the same unit type (length, volume, mass, ...) Options unit is any unit returned by Cldr.Unit.new/2 to_unit is any unit name returned by Cldr.Unit.units/0 Returns a Unit.t of the unit type to_unit or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.convert Cldr.Unit.new!(:celsius, 0), :fahrenheit #Unit&lt;:fahrenheit, 32.0&gt; iex&gt; Cldr.Unit.convert Cldr.Unit.new!(:fahrenheit, 32), :celsius #Unit&lt;:celsius, 0.0&gt; iex&gt; Cldr.Unit.convert Cldr.Unit.new!(:mile, 1), :foot #Unit&lt;:foot, 5279.945925937846&gt; iex&gt; Cldr.Unit.convert Cldr.Unit.new!(:mile, 1), :gallon {:error, {Cldr.Unit.IncompatibleUnitsError, &quot;Operations can only be performed between units of the same type. Received :mile and :gallon&quot;}}"},{"ref":"Cldr.Unit.Conversion.html#convert!/2","title":"Cldr.Unit.Conversion.convert!/2","type":"function","doc":"Convert one unit into another unit of the same unit type (length, volume, mass, ...) and raises on a unit type mismatch Options unit is any unit returned by Cldr.Unit.new/2 to_unit is any unit name returned by Cldr.Unit.units/0 Returns a Unit.t of the unit type to_unit or raises an exception Examples iex&gt; Cldr.Unit.Conversion.convert! Cldr.Unit.new!(:celsius, 0), :fahrenheit #Unit&lt;:fahrenheit, 32.0&gt; iex&gt; Cldr.Unit.Conversion.convert! Cldr.Unit.new!(:fahrenheit, 32), :celsius #Unit&lt;:celsius, 0.0&gt; Cldr.Unit.Conversion.convert Cldr.Unit.new!(:mile, 1), :gallon ** (Cldr.Unit.IncompatibleUnitsError) Operations can only be performed between units of the same type. Received :mile and :gallon"},{"ref":"Cldr.Unit.Conversion.html#direct_factors/0","title":"Cldr.Unit.Conversion.direct_factors/0","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.html#factors/0","title":"Cldr.Unit.Conversion.factors/0","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html","title":"Cldr.Unit.Conversion.FunctionFactors","type":"module","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html#factors/0","title":"Cldr.Unit.Conversion.FunctionFactors.factors/0","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html#from_fahrenheit/1","title":"Cldr.Unit.Conversion.FunctionFactors.from_fahrenheit/1","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html#from_kelvin/1","title":"Cldr.Unit.Conversion.FunctionFactors.from_kelvin/1","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html#to_fahrenheit/1","title":"Cldr.Unit.Conversion.FunctionFactors.to_fahrenheit/1","type":"function","doc":""},{"ref":"Cldr.Unit.Conversion.FunctionFactors.html#to_kelvin/1","title":"Cldr.Unit.Conversion.FunctionFactors.to_kelvin/1","type":"function","doc":""},{"ref":"Cldr.Unit.IncompatibleUnitsError.html","title":"Cldr.Unit.IncompatibleUnitsError","type":"exception","doc":""},{"ref":"Cldr.Unit.Math.html","title":"Cldr.Unit.Math","type":"module","doc":"Simple arithmetic functions for the Unit.t type"},{"ref":"Cldr.Unit.Math.html#add/2","title":"Cldr.Unit.Math.add/2","type":"function","doc":"Adds two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the sum of unit_1 and the potentially converted unit_2 or {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:foot, 1) #Unit&lt;:foot, 2&gt; iex&gt; Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:mile, 1) #Unit&lt;:foot, 5280.945925937846&gt; iex&gt; Cldr.Unit.Math.add Cldr.Unit.new!(:foot, 1), Cldr.Unit.new!(:gallon, 1) {:error, {Cldr.Unit.IncompatibleUnitsError, &quot;Operations can only be performed between units of the same type. Received #Unit&lt;:foot, 1&gt; and #Unit&lt;:gallon, 1&gt;&quot;}}"},{"ref":"Cldr.Unit.Math.html#add!/2","title":"Cldr.Unit.Math.add!/2","type":"function","doc":"Adds two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the sum of unit_1 and the potentially converted unit_2 or Raises an exception"},{"ref":"Cldr.Unit.Math.html#cmp/2","title":"Cldr.Unit.Math.cmp/2","type":"function","doc":"Compare two units, converting to a common unit type if required. If conversion is performed, the results are both rounded to a single decimal place before comparison. Returns :gt, :lt, or :eq. Example iex&gt; x = Cldr.Unit.new(:kilometer, 1) iex&gt; y = Cldr.Unit.new(:meter, 1000) iex&gt; Cldr.Unit.Math.cmp x, y :eq"},{"ref":"Cldr.Unit.Math.html#div/2","title":"Cldr.Unit.Math.div/2","type":"function","doc":"Divides one compatible %Unit{} type by another Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the dividend of unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit.div Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1) #Unit&lt;:kilogram, 11.023100000000001&gt; iex&gt; Cldr.Unit.div Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1) #Unit&lt;:pint, 2.365878355998448&gt; iex&gt; Cldr.Unit.div Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1) #Unit&lt;:pint, 5.0&gt;"},{"ref":"Cldr.Unit.Math.html#div!/2","title":"Cldr.Unit.Math.div!/2","type":"function","doc":"Divides one compatible %Unit{} type by another and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the dividend of unit_1 and the potentially converted unit_2 Raises an exception"},{"ref":"Cldr.Unit.Math.html#mult/2","title":"Cldr.Unit.Math.mult/2","type":"function","doc":"Multiplies two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the product of unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit.mult Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1) #Unit&lt;:kilogram, 2.2679645471781984&gt; iex&gt; Cldr.Unit.mult Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1) #Unit&lt;:pint, 10.566899999999999&gt; iex&gt; Cldr.Unit.mult Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1) #Unit&lt;:pint, 5&gt;"},{"ref":"Cldr.Unit.Math.html#mult!/2","title":"Cldr.Unit.Math.mult!/2","type":"function","doc":"Multiplies two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the product of unit_1 and the potentially converted unit_2 Raises an exception"},{"ref":"Cldr.Unit.Math.html#round/3","title":"Cldr.Unit.Math.round/3","type":"function","doc":"Rounds the value of a unit. Options unit is any unit returned by Cldr.Unit.new/2 places is the number of decimal places to round to. The default is 0. mode is the rounding mode to be applied. The default is :half_up. Returns A %Unit{} of the same type as unit with a value that is rounded to the specified number of decimal places Rounding modes Directed roundings: :down - Round towards 0 (truncate), eg 10.9 rounds to 10.0 :up - Round away from 0, eg 10.1 rounds to 11.0. (Non IEEE algorithm) :ceiling - Round toward +∞ - Also known as rounding up or ceiling :floor - Round toward -∞ - Also known as rounding down or floor Round to nearest: :half_even - Round to nearest value, but in a tiebreak, round towards the nearest value with an even (zero) least significant bit, which occurs 50% of the time. This is the default for IEEE binary floating-point and the recommended value for decimal. :half_up - Round to nearest value, but in a tiebreak, round away from 0. This is the default algorithm for Erlang&#39;s Kernel.round/2 :half_down - Round to nearest value, but in a tiebreak, round towards 0 (Non IEEE algorithm) Examples iex&gt; Cldr.Unit.round Cldr.Unit.new(:yard, 1031.61), 1 #Unit&lt;:yard, 1031.6&gt; iex&gt; Cldr.Unit.round Cldr.Unit.new(:yard, 1031.61), 2 #Unit&lt;:yard, 1031.61&gt; iex&gt; Cldr.Unit.round Cldr.Unit.new(:yard, 1031.61), 1, :up #Unit&lt;:yard, 1031.7&gt;"},{"ref":"Cldr.Unit.Math.html#sub/2","title":"Cldr.Unit.Math.sub/2","type":"function","doc":"Subtracts two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the difference between unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit.sub Cldr.Unit.new!(:kilogram, 5), Cldr.Unit.new!(:pound, 1) #Unit&lt;:kilogram, 4.54640709056436&gt; iex&gt; Cldr.Unit.sub Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:liter, 1) #Unit&lt;:pint, 2.88662&gt; iex&gt; Cldr.Unit.sub Cldr.Unit.new!(:pint, 5), Cldr.Unit.new!(:pint, 1) #Unit&lt;:pint, 4&gt;"},{"ref":"Cldr.Unit.Math.html#sub!/2","title":"Cldr.Unit.Math.sub!/2","type":"function","doc":"Subtracts two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the difference between unit_1 and the potentially converted unit_2 Raises an exception"},{"ref":"Cldr.Unit.Math.html#trunc/1","title":"Cldr.Unit.Math.trunc/1","type":"function","doc":""},{"ref":"Cldr.Unit.UnitNotConvertibleError.html","title":"Cldr.Unit.UnitNotConvertibleError","type":"exception","doc":""},{"ref":"Cldr.Unit.UnknownUnitTypeError.html","title":"Cldr.Unit.UnknownUnitTypeError","type":"exception","doc":""},{"ref":"readme.html","title":"Cldr for Units","type":"extras","doc":"Cldr for Units"},{"ref":"readme.html#getting-started","title":"Cldr for Units - Getting Started","type":"extras","doc":"ex_cldr_units is an add-on library for ex_cldr that provides localisation and formatting for units such as weights, lengths, areas, volumes and so on. It also provides unit conversion and simple arithmetic for compatible units. Configuration From ex_cldr version 2.0, a backend module must be defined into which the public API and the CLDR data is compiled. See the ex_cldr documentation for further information on configuration. In the following examples we assume the presence of a module called MyApp.Cldr defined as: defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;fr&quot;], default_locale: &quot;en&quot; end Supporting the String.Chars protocol The String.Chars protocol underpins Kernel.to_string/1 and is also used in string interpolation such as \#{my_unit}. In order for this to be supported by Cldr.Unit, a default backend module must be configured in config.exs. For example: config :ex_cldr_units, default_backend: MyApp.Cldr"},{"ref":"readme.html#public-api","title":"Cldr for Units - Public API","type":"extras","doc":"The primary api is defined by three functions: MyApp.Cldr.Unit.to_string/2 for formatting units MyApp.Cldr.Unit.new/2 to create a new Unit.t struct that encapsulated a unit and a value that can be used for arithmetic, comparison and conversion MyApp.Cldr.Unit.convert/2 to convert one compatible unit to another MyApp.Cldr.Unit.add/2, MyApp.Cldr.Unit.sub/2, MyApp.Cldr.Unit.mult/2, MyApp.Cldr.Unit.div/2 provide basic arithmetic operations on compatible Unit.t structs. Unit formatting and localization MyApp.Cldr.Unit.to_string/2 provides localized unit formatting. It supports two arguments: number is any number (integer, float or Decimal) or a Unit.t struct returned by Cldr.Unit.new/2 options are: unit is any unit returned by Cldr.Unit.units/0. This option is required unless a Unit.t is passed as the first argument. locale is any configured locale. See Cldr.known_locales(). The default is locale: Cldr.get_current_locale() style is one of those returned by Cldr.Unit.available_styles. The current styles are :long, :short and :narrow. The default is style: :long Any other options are passed to Cldr.Number.to_string/2 which is used to format the number iex&gt; MyApp.Cldr.Unit.to_string 123, unit: :gallon {:ok, &quot;123 gallons&quot;} iex&gt; MyApp.Cldr.Unit.to_string 1234, unit: :gallon, format: :long {:ok, &quot;1 thousand gallons&quot;} iex&gt; MyApp.Cldr.Unit.to_string 1234, unit: :gallon, format: :short {:ok, &quot;1K gallons&quot;} iex&gt; MyApp.Cldr.Unit.to_string 1234, unit: :megahertz {:ok, &quot;1,234 megahertz&quot;} iex&gt; MyApp.Cldr.Unit.to_string 1234, unit: :foot, locale: &quot;fr&quot; {:ok, &quot;1 234 pieds&quot;} iex&gt; MyApp.Cldr.Unit.to_string Cldr.Unit.new(:ampere, 42), locale: &quot;fr&quot; {:ok, &quot;42 ampères&quot;} Unit decomposition Sometimes its a requirement to decompose a unit into one or more subunits. For example, if someone is 6.3 feet heigh we would normally say &quot;6 feet, 4 inches&quot;. This can be achieved with Cldr.Unit.decompose/2. Using our example: iex&gt; height = Cldr.Unit.new(:foot, 6.3) #Unit&lt;:foot, 6.3&gt; iex(2)&gt; Cldr.Unit.decompose height, [:foot, :inch] [#Unit&lt;:foot, 6.0&gt;, #Unit&lt;:inch, 4.0&gt;] A localised string representing this decomposition can also be produced. Cldr.Unit.to_string/3 will process a unit list, using the function Cldr.List.to_string/2 to perform the list combination. Again using the example: iex&gt; c = Cldr.Unit.decompose height, [:foot, :inch] [#Unit&lt;:foot, 6.0&gt;, #Unit&lt;:inch, 4.0&gt;] iex&gt; Cldr.Unit.to_string c, MyApp.Cldr &quot;6 feet and 4 inches&quot; iex&gt; Cldr.Unit.to_string c, MyApp.Cldr, list_options: [format: :unit_short] &quot;6 feet, 4 inches&quot; # And of course full localisation is supported iex&gt; Cldr.Unit.to_string c, MyApp.Cldr, locale: &quot;fr&quot; &quot;6 pieds et 4 pouces&quot; Converting Units Unit.t structs can be converted to other compatible units. For example, feet can be converted to meters since they are both the length unit type. # Test for unit compatibility iex&gt; MyApp.Cldr.Unit.compatible? :foot, :meter true iex&gt; MyApp.Cldr.Unit.compatible? :foot, :liter false # Convert a unit iex&gt; MyApp.Cldr.Unit.convert MyApp.Cldr.Unit.new(:foot, 3), :meter #Unit&lt;:meter, 0.9144111192392099&gt; # What units are compatible? iex&gt; MyApp.Cldr.Unit.compatible_units :foot [:astronomical_unit, :centimeter, :decimeter, :fathom, :foot, :furlong, :inch, :kilometer, :light_year, :meter, :micrometer, :mile, :mile_scandinavian, :millimeter, :nanometer, :nautical_mile, :parsec, :picometer, :point, :yard] Unit arithmetic Basic arithmetic is provided by Cldr.Unit.add/2, Cldr.Unit.sub/2, Cldr.Unit.mult/2, Cldr.Unit.div/2 as well as Cldr.Unit.round/3 iex&gt; MyApp.Cldr.Unit.Math.add MyApp.Cldr.Unit.new!(:foot, 1), MyApp.Cldr.Unit.new!(:foot, 1) #Unit&lt;:foot, 2&gt; iex&gt; MyApp.Cldr.Unit.Math.add MyApp.Cldr.Unit.new!(:foot, 1), MyApp.Cldr.Unit.new!(:mile, 1) #Unit&lt;:foot, 5280.945925937846&gt; iex&gt; MyApp.Cldr.Unit.Math.add MyApp.Cldr.Unit.new!(:foot, 1), MyApp.Cldr.Unit.new!(:gallon, 1) {:error, {Cldr.Unit.IncompatibleUnitError, &quot;Operations can only be performed between units of the same type. Received #Unit&lt;:foot, 1&gt; and #Unit&lt;:gallon, 1&gt;&quot;}} iex&gt; MyApp.Cldr.Unit.round MyApp.Cldr.Unit.new(:yard, 1031.61), 1 #Unit&lt;:yard, 1031.6&gt; iex&gt; MyApp.Cldr.Unit.round MyApp.Cldr.Unit.new(:yard, 1031.61), 1, :up #Unit&lt;:yard, 1031.7&gt; Available units Available units are returned by MyApp.Cldr.Unit.units/0. iex&gt; MyApp.Cldr.Unit.units [:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit, :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century, :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter, :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter, :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong, :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz, :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower, :hour, :inch, ...] Unit types Units are grouped by unit type which defines the convertibility of different types. In general, units of the same time are convertible to each other. The function MyApp.Cldr.Unit.unit_types/0 returns the unit types. MyApp.Cldr.Unit.unit_tree/0 returns the map of all unit types and their child units. iex&gt; MyApp.Cldr.Unit.unit_types [:acceleration, :angle, :area, :concentr, :consumption, :coordinate, :digital, :duration, :electric, :energy, :frequency, :length, :light, :mass, :power, :pressure, :speed, :temperature, :volume]"},{"ref":"readme.html#further-information","title":"Cldr for Units - Further information","type":"extras","doc":"For help in iex: iex&gt; h MyApp.Cldr.Unit.new iex&gt; h MyApp.Cldr.Unit.to_string iex&gt; h MyApp.Cldr.Unit.convert iex&gt; h MyApp.Cldr.Unit.units iex&gt; h MyApp.Cldr.Unit.unit_types"},{"ref":"readme.html#installation","title":"Cldr for Units - Installation","type":"extras","doc":"Note that :ex_cldr_units requires Elixir 1.5 or later. Add ex_cldr_units as a dependency to your mix project: defp deps do [ {:ex_cldr_units, &quot;~&gt; 2.0&quot;} ] end then retrieve ex_cldr_units from hex: mix deps.get mix deps.compile"},{"ref":"changelog.html","title":"Changelog for Cldr_Units v2.5.1","type":"extras","doc":"Changelog for Cldr_Units v2.5.1 This is the changelog for Cldr_units v2.5.1 released on June 18th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Standardize the development cldr backend as MyApp.Cldr which makes for more understandable and readable examples and doc tests Cldr.Unit.to_string/3 now allows for the backend parameter to default to Cldr.default_backend/0 Changelog for Cldr_Units v2.5.0 This is the changelog for Cldr_units v2.5.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.0.0 released on March 27th 2019. Changelog for Cldr_Units v2.4.0 This is the changelog for Cldr_units v2.4.0 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Supports Cldr.default_backend() as a default for backend parameters in Cldr.Unit Changelog for Cldr_Units v2.3.3 This is the changelog for Cldr_units v2.3.2 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Include priv directory in the hex package (thats where the conversion json exists) Changelog for Cldr_Units v2.3.2 This is the changelog for Cldr_units v2.3.2 released on March 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix dialyzer warnings Changelog for Cldr_Units v2.3.1 This is the changelog for Cldr_units v2.3.1 released on March 15th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Makes generation of documentation for backend modules optional. This is implemented by the :generate_docs option to the backend configuration. The default is true. For example: defmodule MyApp.Cldr do use Cldr, default_locale: &quot;en-001&quot;, locales: [&quot;en&quot;, &quot;ja&quot;], gettext: MyApp.Gettext, generate_docs: false end Changelog for Cldr_Units v2.3.0 This is the changelog for Cldr_units v2.3.0 released on March 4th, 2019. For older changelogs please consult the release tag on GitHub Enhancements The conversion tables are now stored as json and updates may be downloaded at any time with the mix task mix cldr.unit.download. This means that updates to the conversion table may be made without requiring a new release of Cldr.Unit. Changelog for Cldr_Units v2.2.0 This is the changelog for Cldr_units v2.2.0 released on February 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements This release is primarily about improving the conversion of units without introducing precision errors that accumulate for floats. The strategy is to define the conversion value between individual unit pairs. Currently the implementation uses a static map. In order to give users a better experience a future release will allow for both specifying mappings as a parameter to Cldr.Unit.convert/2 and as compile time configuration options including the option to download conversion tables from the internet. Direct conversions are now supported. For some calculations, the process of diving and multiplying by conversion factors produces an unexpected result. Some direct conversions are now defined which produce a more expected result. In most cases, return integer values from conversion and decomposition when the originating unit value is also an integer Changelog for Cldr_Units v2.1.0 This is the changelog for Cldr_units v2.1.0 released on December 8th, 2018. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.Conversion.convert!/2 Add Cldr.Unit.Math.cmp/2 Add Cldr.Unit.decompose/2 Add Cldr.Unit.zero/1 Add Cldr.Unit.zero?/1 The appropriate backend equivalents are also added. Changelog for Cldr_Units v2.0.0 This is the changelog for Cldr_units v2.0.0 released on November 24th, 2018. For older changelogs please consult the release tag on GitHub Breaking changes Cldr.Unit now requires a Cldr backend module to be configured In order for the String.Chars protocol to be supported (which is used in string interpolation and by Kernel.to_string/1) a default backend must be configured. For example in config.exs: config :ex_cldr_units, default_backend: MyApp.Cldr Enhancements Move to a backend module structure with ex_cldr version 2.0"},{"ref":"license.html","title":"LICENSE","type":"extras","doc":""},{"ref":"license.html#license","title":"LICENSE - License","type":"extras","doc":"Copyright 2017 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."}]